<?php
/*
Plugin Name: Translate Buttons Change Text for WooCommerce (EasyToolsWP)
Description: A plugin to change WooCommerce button texts.
Version: 1.3
Author: EasyToolsWP.com
*/

// Tilføj en underside under Indstillinger
function cbtt_add_admin_menu() {
    add_options_page(
        'Custom Button Text',
        'Custom Button Text',
        'manage_options',
        'custom_button_text',
        'cbtt_options_page'
    );
}
add_action('admin_menu', 'cbtt_add_admin_menu');

// Registrer indstillinger
function cbtt_settings_init() {
    register_setting('cbtt_options_group', 'cbtt_options');

    add_settings_section(
        'cbtt_settings_section',
        __('Button Texts', 'cbtt'),
        'cbtt_settings_section_callback',
        'custom_button_text'
    );

    $buttons = [
        'add_to_cart' => __('Add to Cart', 'cbtt'),
        'view_cart' => __('View Cart', 'cbtt'),
        'checkout' => __('Checkout', 'cbtt'),
        'continue_shopping' => __('Continue Shopping', 'cbtt'),
        'select_options' => __('Select Options', 'cbtt'),
        'update_cart' => __('Update Cart', 'cbtt'),
        'apply_coupon' => __('Apply Coupon', 'cbtt'),
        'place_order' => __('Place Order', 'cbtt'),
    ];

    foreach ($buttons as $id => $default_text) {
        add_settings_field(
            "cbtt_{$id}_text",
            $default_text,
            function() use ($id) {
                $options = get_option('cbtt_options');
                $text = $options[$id . '_text'] ?? $default_text;
                echo "<input type='text' name='cbtt_options[{$id}_text]' value='" . esc_attr($text) . "'>";
            },
            'custom_button_text',
            'cbtt_settings_section'
        );
    }
}
add_action('admin_init', 'cbtt_settings_init');

function cbtt_settings_section_callback() {
    echo __('Set the button texts for WooCommerce.', 'cbtt');
}

// Ændre knaptekster
function cbtt_custom_button_text() {
    $options = get_option('cbtt_options');

    // Add to Cart
    if (!empty($options['add_to_cart_text'])) {
        add_filter('woocommerce_product_single_add_to_cart_text', function() use ($options) {
            return $options['add_to_cart_text'];
        });
    }

    // View Cart
    if (!empty($options['view_cart_text'])) {
        add_filter('woocommerce_add_to_cart_fragments', function($fragments) use ($options) {
            if (isset($fragments['a.cart-contents'])) {
                $fragments['a.cart-contents'] = str_replace('View Cart', $options['view_cart_text'], $fragments['a.cart-contents']);
            }
            return $fragments;
        });
    }

    // Checkout
    if (!empty($options['checkout_text'])) {
        add_filter('woocommerce_checkout_button', function() use ($options) {
            return $options['checkout_text'];
        }, 20);
    }

    // Continue Shopping
    if (!empty($options['continue_shopping_text'])) {
        add_filter('woocommerce_continue_shopping_redirect', function() use ($options) {
            return $options['continue_shopping_text'];
        });
    }

    // Select Options
    if (!empty($options['select_options_text'])) {
        add_filter('woocommerce_variable_add_to_cart_text', function() use ($options) {
            return $options['select_options_text'];
        });
    }

    // Update Cart
    if (!empty($options['update_cart_text'])) {
        add_filter('woocommerce_cart_update_url', function() use ($options) {
            return $options['update_cart_text'];
        });
    }

    // Apply Coupon
    if (!empty($options['apply_coupon_text'])) {
        add_filter('woocommerce_cart_coupon_label', function() use ($options) {
            return $options['apply_coupon_text'];
        });
    }

    // Place Order
    if (!empty($options['place_order_text'])) {
        add_filter('woocommerce_order_button_text', function() use ($options) {
            return $options['place_order_text'];
        });
    }
}
add_action('wp', 'cbtt_custom_button_text');

// Options side HTML
function cbtt_options_page() {
    ?>
    <div class="wrap">
        <h1><?php _e('Custom Button Text', 'cbtt'); ?></h1>
        <form action='options.php' method='post'>
            <?php
            settings_fields('cbtt_options_group');
            do_settings_sections('custom_button_text');
            submit_button(__('Save Changes', 'cbtt'));
            ?>
        </form>
    </div>
    <?php
}
